@@ -57,14 +57,11 @@ information about contributing is in the github repository.
 
 """
 
-import sys
-from pkg_resources import get_distribution, DistributionNotFound
-if sys.version_info < (3, 6):
-    raise ImportError("GWCS supports Python versions 3.6 and above.")  # pragma: no cover
+import importlib.metadata
 
 try:
-    __version__ = get_distribution(__name__).version
-except DistributionNotFound:  # pragma: no cover
+    __version__ = importlib.metadata.version(__name__)
+except importlib.metadata.PackageNotFoundError:  # pragma: no cover
     # package is not installed
     pass  # pragma: no cover
 
