@@ -117,11 +117,8 @@ class GWCSAPIMixin(BaseHighLevelWCS, BaseLowLevelWCS):
         ``i`` is the row and ``j`` is the column (i.e. the opposite order to
         `~BaseLowLevelWCS.pixel_to_world_values`).
         """
-        index_arrays = self._add_units_input(index_arrays[::-1], self.forward_transform, self.input_frame)
-
-        result = self(*index_arrays, with_units=False)
-
-        return self._remove_quantity_output(result, self.output_frame)
+        pixel_arrays = index_arrays[::-1]
+        return self.pixel_to_world_values(*pixel_arrays)
 
     def world_to_pixel_values(self, *world_arrays):
         """
@@ -150,12 +147,10 @@ class GWCSAPIMixin(BaseHighLevelWCS, BaseLowLevelWCS):
         `~BaseLowLevelWCS.pixel_to_world_values`). The indices should be
         returned as rounded integers.
         """
-        world_arrays = self._add_units_input(world_arrays, self.backward_transform, self.output_frame)
-        result = self.invert(*world_arrays, with_units=False)
+        result = self.world_to_pixel_values(*world_arrays)
         if self.pixel_n_dim != 1:
             result = result[::-1]
-
-        return self._remove_quantity_output(result, self.input_frame)
+        return result
 
     @property
     def array_shape(self):
@@ -170,11 +165,17 @@ class GWCSAPIMixin(BaseHighLevelWCS, BaseLowLevelWCS):
         The shape should be given in ``(row, column)`` order (the convention
         for arrays in Python).
         """
-        return self._array_shape
+        if self._pixel_shape is None:
+            return None
+        else:
+            return self._pixel_shape[::-1]
 
     @array_shape.setter
     def array_shape(self, value):
-        self._array_shape = value
+        if value is None:
+            self._pixel_shape = None
+        else:
+            self._pixel_shape = value[::-1]
 
     @property
     def pixel_bounds(self):
