@@ -40,7 +40,7 @@ def test_LabelMapperArray_from_vertices_string():
 
 # These tests below check the scanning algorithm for two shapes
 def polygon1(shape=(9, 9)):
-    ar = np.zeros(shape)
+    ar = np.zeros(shape, dtype=int)
     ar[1, 2] = 1
     ar[2][2:4] = 1
     ar[3][1:4] = 1
@@ -48,12 +48,12 @@ def polygon1(shape=(9, 9)):
     ar[5][1:4] = 1
     ar[6][2:7] = 1
     ar[7][3:6] = 1
-    # ar[8][3:4] =1 ##need to include this in the future if padding top and left
+    ar[8][3:4] = 1
     return ar
 
 
 def two_polygons():
-    ar = np.zeros((301, 301))
+    ar = np.zeros((301, 301), dtype=int)
     ar[1, 2] = 1
     ar[2][2:4] = 1
     ar[3][1:4] = 1
@@ -61,7 +61,8 @@ def two_polygons():
     ar[5][1:4] = 1
     ar[6][2:7] = 1
     ar[7][3:6] = 1
-    ar[:30, 10:31] = 2
+    ar[8][3:4] = 1
+    ar[:31, 10:31] = 2
     return ar
 
 
